@@ -1,7 +1,5 @@
 from allauth.socialaccount.providers.base import AuthAction, ProviderAccount
-from allauth.socialaccount.providers.microsoft.views import (
-    MicrosoftGraphOAuth2Adapter,
-)
+from allauth.socialaccount.providers.microsoft.views import MicrosoftGraphOAuth2Adapter
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
@@ -9,10 +7,6 @@ class MicrosoftGraphAccount(ProviderAccount):
     def get_avatar_url(self):
         return self.account.extra_data.get("photo")
 
-    def to_str(self):
-        dflt = super(MicrosoftGraphAccount, self).to_str()
-        return self.account.extra_data.get("displayName", dflt)
-
 
 class MicrosoftGraphProvider(OAuth2Provider):
     id = "microsoft"
