@@ -1,8 +1,6 @@
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
-from allauth.socialaccount.providers.twitter_oauth2.views import (
-    TwitterOAuth2Adapter,
-)
+from allauth.socialaccount.providers.twitter_oauth2.views import TwitterOAuth2Adapter
 
 
 class TwitterOAuth2Account(ProviderAccount):
@@ -12,7 +10,7 @@ class TwitterOAuth2Account(ProviderAccount):
     def get_profile_url(self):
         username = self.get_username()
         if username:
-            return "https://twitter.com/" + username
+            return "https://x.com/" + username
         return None
 
     def get_avatar_url(self):
@@ -21,7 +19,7 @@ class TwitterOAuth2Account(ProviderAccount):
 
 class TwitterOAuth2Provider(OAuth2Provider):
     id = "twitter_oauth2"
-    name = "Twitter"
+    name = "X"
     account_class = TwitterOAuth2Account
     oauth2_adapter_class = TwitterOAuth2Adapter
     pkce_enabled_default = True
